@@ -1,4 +1,4 @@
-/* $Id: buffer.c,v 1.27 2003/02/03 15:49:19 ukai Exp $ */
+/* $Id: buffer.c,v 1.29 2003/09/26 17:59:51 ukai Exp $ */
 #include "fm.h"
 
 #ifdef USE_MOUSE
@@ -43,6 +43,9 @@ newBuffer(int width)
     n->trbyte = 0;
 #ifdef USE_SSL
     n->ssl_certificate = NULL;
+#endif
+#ifdef USE_M17N
+    n->auto_detect = WcOption.auto_detect;
 #endif
     return n;
 }
@@ -204,6 +207,7 @@ writeBufferName(Buffer *buf, int n)
     if (all == 0 && buf->lastLine != NULL)
 	all = buf->lastLine->linenumber;
     move(n, 0);
+    /* FIXME: gettextize? */
     msg = Sprintf("<%s> [%d lines]", buf->buffername, all);
     if (buf->filename != NULL) {
 	switch (buf->currentURL.scheme) {
@@ -245,6 +249,7 @@ gotoLine(Buffer *buf, int n)
 	       (getNextPage(buf, 1) != NULL)) ;
     }
     if (l->linenumber > n) {
+	/* FIXME: gettextize? */
 	sprintf(msg, "First line is #%ld", l->linenumber);
 	set_delayed_message(msg);
 	buf->topLine = buf->currentLine = l;
@@ -252,6 +257,7 @@ gotoLine(Buffer *buf, int n)
     }
     if (buf->lastLine->linenumber < n) {
 	l = buf->lastLine;
+	/* FIXME: gettextize? */
 	sprintf(msg, "Last line is #%ld", buf->lastLine->linenumber);
 	set_delayed_message(msg);
 	buf->currentLine = l;
@@ -288,6 +294,7 @@ gotoRealLine(Buffer *buf, int n)
 	       (getNextPage(buf, 1) != NULL)) ;
     }
     if (l->real_linenumber > n) {
+	/* FIXME: gettextize? */
 	sprintf(msg, "First line is #%ld", l->real_linenumber);
 	set_delayed_message(msg);
 	buf->topLine = buf->currentLine = l;
@@ -295,6 +302,7 @@ gotoRealLine(Buffer *buf, int n)
     }
     if (buf->lastLine->real_linenumber < n) {
 	l = buf->lastLine;
+	/* FIXME: gettextize? */
 	sprintf(msg, "Last line is #%ld", buf->lastLine->real_linenumber);
 	set_delayed_message(msg);
 	buf->currentLine = l;
@@ -352,6 +360,7 @@ listBuffer(Buffer *top, Buffer *current)
 	buf = buf->nextBuffer;
     }
     standout();
+    /* FIXME: gettextize? */
     message("Buffer selection mode: SPC for select / D for delete buffer", 0,
 	    0);
     standend();
@@ -496,6 +505,9 @@ reshapeBuffer(Buffer *buf)
 {
     URLFile f;
     Buffer sbuf;
+#ifdef USE_M17N
+    wc_uint8 old_auto_detect = WcOption.auto_detect;
+#endif
 
     if (!buf->need_reshape)
 	return;
@@ -542,18 +554,18 @@ reshapeBuffer(Buffer *buf)
 	    readHeader(&f, buf, TRUE, NULL);
     }
 
-#ifdef JP_CHARSET
+#ifdef USE_M17N
+    WcOption.auto_detect = WC_OPT_DETECT_OFF;
     UseContentCharset = FALSE;
-    UseAutoDetect = FALSE;
 #endif
     if (!strcasecmp(buf->type, "text/html"))
 	loadHTMLBuffer(&f, buf);
     else
 	loadBuffer(&f, buf);
     UFclose(&f);
-#ifdef JP_CHARSET
+#ifdef USE_M17N
+    WcOption.auto_detect = old_auto_detect;
     UseContentCharset = TRUE;
-    UseAutoDetect = TRUE;
 #endif
 
     buf->height = LASTLINE + 1;
