@@ -1,4 +1,4 @@
-/* $Id: istream.c,v 1.23 2003/10/20 16:41:56 ukai Exp $ */
+/* $Id: istream.c,v 1.26 2007/05/23 15:06:05 inu Exp $ */
 #include "fm.h"
 #include "myctype.h"
 #include "istream.h"
@@ -6,6 +6,9 @@
 #ifdef USE_SSL
 #include <openssl/x509v3.h>
 #endif
+#ifdef __MINGW32_VERSION
+#include <winsock.h>
+#endif
 
 #define	uchar		unsigned char
 
@@ -617,13 +620,21 @@ ssl_get_certificate(SSL * ssl, char *hostname)
 static void
 basic_close(int *handle)
 {
+#ifdef __MINGW32_VERSION
+    closesocket(*(int *)handle);
+#else
     close(*(int *)handle);
+#endif
 }
 
 static int
 basic_read(int *handle, char *buf, int len)
 {
+#ifdef __MINGW32_VERSION
+    return recv(*(int *)handle, buf, len, 0);
+#else
     return read(*(int *)handle, buf, len);
+#endif
 }
 
 static void
